@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Math
-Version : 1.0.1
+Version : 1.0.3
 Author  : Stefano Covino
-Date    : 08/11/2010
+Date    : 11/02/2012
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -15,10 +15,14 @@ Remarks :
 
 History : (29/09/2010) First named version.
         : (08/11/2010) Cartesian distance added.
+        : (09/02/2012) Sidereal time, hour and parallactic angles computation added.
+        : (11/02/2012) PointMatch added.
+        : (18/02/2012) Sky functions moved to SRPSky.
 """
 
 
 __all__ = ['AngularDistance', 'AstroAngleInput', 'AstroCoordInput', 'AstroMagInput', 'CartesiamCoordAmpRotoTranslation', 
-            'CartesianDistance', 'InverseCartesiamCoordAmpRotoTranslation','MinDist','PointClass', 'TriangleClass']
+            'CartesianDistance', 'InverseCartesiamCoordAmpRotoTranslation', 'MinDist', 'PointClass', 'PointMatch', 
+            'TriangleClass', 'TriangleMatch']
 
 
