@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : SRP
-Version : 1.0.41
+Version : 1.0.47
 Author  : Stefano Covino
-Date    : 16/12/2011
+Date    : 28/02/2012
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -58,15 +58,26 @@ History : (28/09/2010) First named version.
         : (15/11/2011) V. 3.10.3b3.
         : (10/12/2011) V. 3.10.3b4.
         : (16/12/2011) V. 3.10.3.
+        : (12/01/2012) V. 3.10.4b1.
+        : (12/01/2012) V. 3.10.4b2.
+        : (04/02/2012) V. 3.10.4b3.
+        : (08/02/2012) V. 3.10.4b4.
+        : (14/02/2012) V. 3.10.4b5.
+        : (18/02/2012) V. 3.10.4b6 and SRPSky.
+        : (28/02/2012) V. 3.10.4.
 """
 
 
 
 # import
-__all__ = ['SRPCatalogue','SRPFits','SRPFrames','SRPMath','SRPNet','SRPSpectroscopy','SRPStatistics', 
-            'SRPSystem','SRPTables']
+import pkg_resources
+
+
+__all__ = ['SRPCatalogue', 'SRPFits', 'SRPFrames', 'SRPMath', 'SRPNet', 'SRPPhotometry', 
+           'SRPPipelines', 'SRPPolarimetry', 'SRPREM', 'SRPSky', 'SRPSpectroscopy', 
+           'SRPStatistics', 'SRPSystem', 'SRPTables', 'SRPTNG']
 
 
 # Version
-__version__ = '3.10.3'
+__version__ = '3.10.4'
 
